import{S as p,i as w,s as g,ad as v,k as u,l as _,m,h as d,ae as E,n as l,b,a5 as k,C as q,Z as c}from"../chunks/index.72b3cb36.js";function z(a){let t,e,h,r,s,o,f;return v(a[2]),{c(){t=u("div"),e=u("iframe"),this.h()},l(i){t=_(i,"DIV",{});var n=m(t);e=_(n,"IFRAME",{src:!0,height:!0,width:!0,title:!0}),m(e).forEach(d),n.forEach(d),this.h()},h(){E(e.src,h="http://localhost:8888")||l(e,"src",h),l(e,"height",r=a[1]-a[1]/10),l(e,"width",s=a[0]-a[0]/200),l(e,"title","ledfx iframe")},m(i,n){b(i,t,n),k(t,e),o||(f=q(window,"resize",a[2]),o=!0)},p(i,[n]){n&2&&r!==(r=i[1]-i[1]/10)&&l(e,"height",r),n&1&&s!==(s=i[0]-i[0]/200)&&l(e,"width",s)},i:c,o:c,d(i){i&&d(t),o=!1,f()}}}function C(a,t,e){let h=0,r=0;function s(){e(0,h=window.innerWidth),e(1,r=window.innerHeight)}return[h,r,s]}class I extends p{constructor(t){super(),w(this,t,C,z,g,{})}}export{I as default};
