import{S as i,i as o,s as r,q as c,r as l,b as u,Z as s,h as f}from"../chunks/index.72b3cb36.js";function m(a){let t;return{c(){t=c("Settings")},l(e){t=l(e,"Settings")},m(e,n){u(e,t,n)},p:s,i:s,o:s,d(e){e&&f(t)}}}class d extends i{constructor(t){super(),o(this,t,null,m,r,{})}}export{d as default};
