.mdc-form-field{margin:.25em;padding:.25em;display:flex}.flex-container.svelte-o0xyhd{margin:auto;width:70%;padding:1em;justify-content:center;align-items:center}.cell.svelte-o0xyhd{margin-top:1em;display:flex;justify-content:center;align-items:center}
